DROP VIEW IF EXISTS public.hive_accounts_rank_view CASCADE;

CREATE OR REPLACE VIEW public.hive_accounts_rank_view
 AS
 SELECT rank.id,
        CASE
            WHEN rank."position" < 200 THEN 70
            WHEN rank."position" < 1000 THEN 60
            WHEN rank."position" < 6500 THEN 50
            WHEN rank."position" < 25000 THEN 40
            WHEN rank."position" < 100000 THEN 30
            ELSE 20
        END AS score
FROM
( SELECT ha2.id,
         rank() OVER (ORDER BY ha2.reputation DESC) AS "position"
  FROM hive_accounts ha2
) rank
;

DROP FUNCTION IF EXISTS public.calculate_notify_vote_score(_payout hive_posts.payout%TYPE, _abs_rshares hive_posts_view.abs_rshares%TYPE, _rshares hive_votes.rshares%TYPE) CASCADE
;
CREATE OR REPLACE FUNCTION public.calculate_notify_vote_score(_payout hive_posts.payout%TYPE, _abs_rshares hive_posts_view.abs_rshares%TYPE, _rshares hive_votes.rshares%TYPE)
RETURNS INT
LANGUAGE 'sql'
IMMUTABLE
AS $BODY$
    SELECT CASE
        WHEN ((( _payout )/_abs_rshares) * 1000 * _rshares < 20 ) THEN -1
            ELSE LEAST(100, (LENGTH(CAST( CAST( ( (( _payout )/_abs_rshares) * 1000 * _rshares ) as BIGINT) as text)) - 1) * 25)
    END;
$BODY$;




DROP FUNCTION IF EXISTS notification_id CASCADE;
;
CREATE OR REPLACE FUNCTION notification_id(in _block_number INTEGER, in _notifyType INTEGER, in _id INTEGER)
RETURNS BIGINT
AS
$function$
BEGIN
RETURN CAST( _block_number as BIGINT ) << 32
       | ( _notifyType << 16 )
       | ( _id & CAST( x'0000FFFF' as INTEGER) );
END
$function$
LANGUAGE plpgsql IMMUTABLE
;

-- View: public.hive_raw_notifications_as_view

DROP VIEW IF EXISTS public.hive_raw_notifications_as_view CASCADE;

CREATE OR REPLACE VIEW public.hive_raw_notifications_as_view
 AS
 SELECT notifs.block_num,
    notifs.id,
    notifs.post_id,
    notifs.type_id,
    notifs.created_at,
    notifs.src,
    notifs.dst,
    notifs.dst_post_id,
    notifs.community,
    notifs.community_title,
    notifs.payload,
    harv.score
   FROM ( SELECT hpv.block_num,
            notification_id(hpv.block_num,
                CASE hpv.depth
                    WHEN 1 THEN 12
                    ELSE 13
                END, hpv.id) AS id,
            hpv.parent_id AS post_id,
                CASE hpv.depth
                    WHEN 1 THEN 12
                    ELSE 13
                END AS type_id,
            hpv.created_at,
            hpv.author_id AS src,
            hpv.parent_author_id AS dst,
            hpv.parent_id as dst_post_id,
            ''::character varying(16) AS community,
            ''::character varying AS community_title,
            ''::character varying AS payload
           FROM hive_posts_pp_view hpv
                  WHERE hpv.block_num >= block_before_head('90 days'::interval) and hpv.depth > 0 AND
                        NOT EXISTS (SELECT NULL::text
                                    FROM hive_follows hf
                                    WHERE hf.follower = hpv.parent_author_id AND hf.following = hpv.author_id AND hf.state = 2)
        UNION ALL
         SELECT hf.block_num,
            notification_id(hf.block_num, 15, hf.id) AS id,
            0 AS post_id,
            15 AS type_id,
            hf.created_at,
            hf.follower AS src,
            hf.following AS dst,
            0 as dst_post_id,
            ''::character varying(16) AS community,
            ''::character varying AS community_title,
            ''::character varying AS payload
           FROM hive_follows hf
       WHERE hf.block_num >= block_before_head('90 days'::interval)
        UNION ALL
         SELECT hr.block_num,
            notification_id(hr.block_num, 14, hr.id) AS id,
            hp.id AS post_id,
            14 AS type_id,
            hr.created_at,
            hr.blogger_id AS src,
            hp.author_id AS dst,
            hr.post_id as dst_post_id,
            ''::character varying(16) AS community,
            ''::character varying AS community_title,
            ''::character varying AS payload
           FROM hive_reblogs hr
             JOIN hive_posts hp ON hr.post_id = hp.id
       WHERE hr.block_num >= block_before_head('90 days'::interval)
        UNION ALL
         SELECT hs.block_num,
            notification_id(hs.block_num, 11, hs.id) AS id,
            0 AS post_id,
            11 AS type_id,
            hs.created_at,
            hs.account_id AS src,
            hs.community_id AS dst,
            0 as dst_post_id,
            hc.name AS community,
            hc.title AS community_title,
            ''::character varying AS payload
           FROM hive_subscriptions hs
           JOIN hive_communities hc ON hs.community_id = hc.id
       WHERE hs.block_num >= block_before_head('90 days'::interval)
        UNION ALL
         SELECT hm.block_num,
            notification_id(hm.block_num, 16, hm.id) AS id,
            hm.post_id,
            16 AS type_id,
            hp.created_at,
            hp.author_id AS src,
            hm.account_id AS dst,
            hm.post_id as dst_post_id,
            ''::character varying(16) AS community,
            ''::character varying AS community_title,
            ''::character varying AS payload
           FROM hive_mentions hm
           JOIN hive_posts hp ON hm.post_id = hp.id
           WHERE hm.block_num >= block_before_head('90 days'::interval)
    ) notifs
     JOIN hive_accounts_rank_view harv ON harv.id = notifs.src
   ;

drop view if exists hive_raw_notifications_view_noas cascade;
CREATE OR REPLACE VIEW hive_raw_notifications_view_noas
AS
SELECT -- new community
        hc.block_num as block_num
      , notification_id(hc.block_num, 11, hc.id) as id
      , 0 as post_id
      , 1 as type_id
      , hc.created_at as created_at
      , 0 as src
      , hc.id as dst
      , 0 as dst_post_id
      , hc.name as community
      , ''::VARCHAR as community_title
      , ''::VARCHAR as payload
      , 35 as score
  FROM
      hive_communities hc
    where hc.block_num >= block_before_head( '90 days' )
UNION ALL
  SELECT --votes
        hv1.block_num as block_num
      , notification_id(hv1.block_num, 17, CAST( hv1.id as INT) ) as id
      , hpv.id as post_id
      , 17 as type_id
      , hv1.last_update as created_at
      , hv1.voter_id as src
      , hpv.author_id as dst
      , hpv.id as dst_post_id
      , ''::VARCHAR(16) as community
      , ''::VARCHAR as community_title
      , ''::VARCHAR as payload
      , calculate_notify_vote_score( (hpv.payout + hpv.pending_payout), hpv.abs_rshares, hv1.rshares ) as score
  FROM
    hive_votes hv1
    JOIN (SELECT hpvi.id, hpvi.author_id, hpvi.payout, hpvi.pending_payout, hpvi.abs_rshares
      FROM hive_posts_base_view hpvi WHERE hpvi.block_num > block_before_head( '90 days' ) ) as hpv ON hv1.post_id = hpv.id
    WHERE hv1.rshares >= 10e9 and hv1.block_num > block_before_head( '90 days' )
UNION ALL
  SELECT --persistent notifs
       hn.block_num
     , notification_id(hn.block_num, hn.type_id, CAST( hn.id as INT) ) as id
     , hn.post_id as post_id
     , hn.type_id as type_id
     , hn.created_at as created_at
     , hn.src_id as src
     , hn.dst_id as dst
     , hn.post_id as dst_post_id
     , hc.name as community
     , hc.title as community_title
     , hn.payload as payload
     , hn.score as score
  FROM hive_notifs hn
  JOIN hive_communities hc ON hn.community_id = hc.id
  where hn.block_num >= block_before_head( '90 days' )
;

DROP VIEW IF EXISTS hive_raw_notifications_view cascade
;
CREATE OR REPLACE VIEW hive_raw_notifications_view
AS
SELECT *
FROM
  (
  SELECT * FROM hive_raw_notifications_as_view
  UNION ALL
  SELECT * FROM hive_raw_notifications_view_noas
  ) as notifs
WHERE notifs.block_num >= block_before_head( '90 days' ) AND notifs.score >= 0;
